<?php

/**
 * Menu callback; presents menu configuration options - per domain.
 * See domain_menu.module.
 *
 * Function scraped from menu modules menu_configure()
 */
function domain_menu_form() {
  global $_domain;
  $domain_menus = domain_menu_lookup($_domain['domain_id']);

  // Find All memu items excluding the "Navigation" menu
  $root_menus = menu_parent_options(1); 
  $primary_options = $root_menus;
  $primary_options[0] = t('No primary links');

  $form['domain_settings_links'] = array('#type' => 'fieldset',
    '#title' => t('Primary and secondary links settings'),
  );

  $form['domain_settings_links']['intro'] = array('#type' => 'item',
    '#value' => t('Primary and secondary links provide a navigational menu system which usually (depending on your theme) appears at the top-right of the browser window. The links displayed can be generated either from a custom list created via the <a href="@menu">menu administration</a> page or from a built-in list of menu items such as the navigation menu links.', array('@menu' => url('admin/build/menu'))),
  );

  $form['domain_settings_links']['menu_primary_menu'] = array('#type' => 'select',
    '#title' => t('Menu containing primary links'),
    '#default_value' => $domain_menus['primary'] ? $domain_menus['primary'] : 0,
    '#options' => $primary_options,
  );

  $secondary_options = $root_menus;
  $secondary_options[0] = t('No secondary links');

  $form['domain_settings_links']['menu_secondary_menu'] = array('#type' => 'select',
    '#title' => t('Menu containing secondary links'),
    '#default_value' => $domain_menus['secondary'] ? $domain_menus['secondary'] : 0,
    '#options' => $secondary_options,
    '#description' => t('If you select the same menu as primary links then secondary links will display the appropriate second level of your navigation hierarchy.'),
  );

  $form['domain_settings_authoring'] = array('#type' => 'fieldset',
    '#title' => t('Content authoring form settings'),
  );

  $form['domain_settings_authoring']['intro'] = array('#type' => 'item',
    '#value' => t('The menu module allows on-the-fly creation of menu links in the content authoring forms. The following option limits the menus in which a new link may be added. E.g., this can be used to force new menu items to be created in the primary links menu or to hide admin menu items.'),
  );

  $authoring_options = $root_menus;
  $authoring_options[0] = t('Show all menus');

  $form['domain_settings_authoring']['menu_parent_items'] = array('#type' => 'select',
    '#title' => t('Restrict parent items to'),
    '#default_value' => $domain_menus['parent_items'] ? $domain_menus['parent_items'] : 0,
    '#options' => $authoring_options,
    '#description' => t('Choose the menu to be made available in the content authoring form. Only this menu item and its children will be shown.'),
   );

  // Which domain are we editing?
  $form['domain_id'] = array(
    '#type' => 'value',
    '#value' => $_domain['domain_id'],
  );

  // Our submit handlers.
  $form['#submit']['domain_menu_submit'] = array();
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );
  return $form; 
}

function domain_menu_submit($form_id, $form_values) {
  $id = $form_values['domain_id'];
  $check = domain_menu_lookup($id);

  $menus = array();
  $menus['primary'] = $form_values['menu_primary_menu'];
  $menus['secondary'] = $form_values['menu_secondary_menu'];
  $menus['parent_items'] = $form_values['menu_parent_items']; // temp

  $menus = serialize($menus);

  if ($check == -1) {
    db_query("INSERT INTO {domain_menu} (domain_id, menu_settings) VALUES (%d, '%s')", $id, $menus);
  }
  else {
    db_query("UPDATE {domain_menu} SET menu_settings = '%s' WHERE domain_id = %d", $menus, $id);
  }
}
